
RELEASE_VERSION='0.0.461192871.dev3586'
BUILD_DATE='Tue Feb  1 19:23:34 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-057qqr 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2041581892'
GIT_COMMIT_SHA='29aa26b329449ab7cc20ca2703786b5d6cb69219'
GIT_BRANCH='main'
